@@ -1,11 +1,14 @@
 #![feature(proc_macro)]
 
 extern crate proc_macro;
-#[macro_use] extern crate quote;
+extern crate proc_macro2;
+#[macro_use] 
+extern crate quote;
 extern crate syn;
 
 use syn::*;
 use proc_macro::TokenStream;
+use syn::spanned::Spanned;
 
 #[proc_macro_attribute]
 pub fn thread_spawn(_args: TokenStream, input: TokenStream) -> TokenStream {
@@ -49,7 +52,8 @@ pub fn thread_spawn(_args: TokenStream, input: TokenStream) -> TokenStream {
             ret.to_owned()
         }
     };
-    let body = &input.block;
+    let block = input.block;
+    let body = quote_spanned! {block.span()=> #block };
 
     quote!(
         #(#attributes),*
